# this script include analyses of determinants of species area relationship in global
# drylands based on dataset 'SAR_data.csv'


########################## intial part ################################

setwd("C:/Users/niv/Dropbox/R/Biocom_new") # change according to your working directory
library(adespatial) # for spatial eigenvector
library(piecewiseSEM) # for SEM
library(stargazer) # for showing the regression coef
library(party) # for classification tree

######### transformations ###########

Results_all=read.csv("SAR_data.csv",header=TRUE)

# transformation of variables for approximating the normal distribution

Results_all$CVpH=log(Results_all$CVpH)
Results_all$site_richness=log(Results_all$site_richness) # log transformation
Results_all$b1=log(Results_all$b1) # log transformation
Results_all$evenness=log(Results_all$evenness/(1-Results_all$evenness))# logit transformation
Results_all$aggregation=log(Results_all$aggregation)# log transformation
Results_all$aridity=log(Results_all$aridity/(1-Results_all$aridity)) # logit transformation
Results_all$herb_cover[which(Results_all$herb_cover<0)]=0 # remove negative values (these are due to errors in calculation)
eps=0.005 # low number added to avoid infinity in logit transformation
Results_all$herb_cover=log((Results_all$herb_cover/100+eps)/(1-Results_all$herb_cover/100+eps))# calculate logit with eps for avioding infinity
eps=0.05
Results_all$woody_cover=log((Results_all$woody_cover/100+eps)/(1-Results_all$woody_cover/100+eps))# calculate logit with eps for avioding infinity


# remove sites where the logarithmic model does not fit 
Results_all=Results_all[-which(Results_all$R_log<0.90),]# remove sites where Rsquare is lower than 0.9 
# add spatial vectors (based on spatial coordinates)
spatial_eigenvectors=dbmem(as.matrix(Results_all[,c(22,23)]),MEM.autocor="positive")
Results_all=cbind(Results_all,spatial_eigenvectors)



# standardization of variables (mean=0,SD=1) 
zVar=function(myVar) { (myVar - mean(myVar)) / sd(myVar)} # function of standardizaion of variable
Results_all$CVpH=zVar(Results_all$CVpH)
Results_all$aridity=zVar(Results_all$aridity)
Results_all$pH=zVar(Results_all$pH)
Results_all$woody_cover=zVar(Results_all$woody_cover)
Results_all$herb_cover=zVar(Results_all$herb_cover)
Results_all$evenness=zVar(Results_all$evenness)
Results_all$aggregation=zVar(Results_all$aggregation)
Results_all$site_richness=zVar(Results_all$site_richness)
Results_all$b0=zVar(Results_all$b0)
Results_all$b1=zVar(Results_all$b1)


# for appendix S1 showing the scatter plot matrix

panel.hist <- function(x, ...) # function for pairs to show histogram
{
  usr <- par("usr"); on.exit(par(usr))
  par(usr = c(usr[1:2], 0, 1.5) )
  h <- hist(x, plot = FALSE)
  breaks <- h$breaks; nB <- length(breaks)
  y <- h$counts; y <- y/max(y)
  rect(breaks[-nB], 0, breaks[-1], y, col = "cyan", ...)
}


pairs(~evenness+b0+b1+site_richness+aggregation+herb_cover+woody_cover+aridity+CVpH+pH, data=Results_all, diag.panel=panel.hist)

################ structural equation model  ###########################
# this is the final SEM with the lowest AICc Score
## equations##

# SEM equation 1
pH_lm=lm(pH~aridity+
           MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
         data=Results_all)#
# SEM equation 2
CVpH_lm=lm(CVpH~aridity+
             MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
           data=Results_all)#   

# SEM equation 3 
woody_cover_lm=lm(woody_cover~
                    MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
                  data=Results_all)#   

# SEM equation 4
evenness_lm=lm(evenness~
                 MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
               data=Results_all)#   

# SEM equation 5
herb_cover_lm=lm(herb_cover~
                   MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
                 data=Results_all)#   

# SEM equation 6
aggregation_lm=lm(aggregation~
                    MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
                  data=Results_all)#   

# SEM equation 7
b0_lm=lm(b0~evenness+aggregation+aridity+pH+
           MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
         data=Results_all)#   

# SEM equation 8
b1_lm=lm(b1~evenness+aggregation+herb_cover+woody_cover+CVpH+
           MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
         data=Results_all)#   


# SEM equation 9
site_richness_lm=lm(site_richness~aridity+aggregation+
                      MEM1+MEM2+MEM3+MEM4+MEM5+MEM6+MEM7+MEM8+MEM9+MEM10,
                    data=Results_all)#


###testing the model 

SEMequations=list(site_richness_lm,CVpH_lm,pH_lm,evenness_lm,aggregation_lm, herb_cover_lm,woody_cover_lm,b0_lm,b1_lm)
mySEM=sem.fit(SEMequations,data=Results_all,corr.errors = c('pH~~CVpH','woody_cover ~~ herb_cover','b1~~b0','b1~~site_richness','b0~~site_richness',
                                                            'evenness ~~ herb_cover','woody_cover ~~ evenness','woody_cover ~~ aggregation','aggregation~~evenness','herb_cover ~~ aggregation'))
mySEM



# showing all the results in one table
stargazer(pH_lm,CVpH_lm,aggregation_lm,herb_cover_lm,evenness_lm,woody_cover_lm,b0_lm,b1_lm,site_richness_lm, type = 'text',keep=c("aridity",'pH','evenness','aggregation','herb_cover','woody_cover','CVpH'))

# saving the results as html
stargazer(pH_lm,CVpH_lm,aggregation_lm,herb_cover_lm,evenness_lm,woody_cover_lm,b0_lm,b1_lm,site_richness_lm, type = 'html',keep=c("aridity",'pH','evenness','aggregation','herb_cover','woody_cover','CVpH'),out="SEM_SAR.htm")


# estimating the correlations

cor.test(Results_all$herb_cover,Results_all$woody_cover)#-0.59(significant)
cor.test(Results_all$b0,Results_all$b1)#0.08 insignificant
cor.test(Results_all$herb_cover,Results_all$evenness)#-0.39(significant)
cor.test(Results_all$woody_cover,Results_all$evenness)#0.25 (significant)
cor.test(Results_all$woody_cover,Results_all$aggregation)#-0.09 (non-significant)
cor.test(Results_all$b0,Results_all$site_richness)#0.42 significant
cor.test(Results_all$site_richness,Results_all$b1)#0.93 significant
cor.test(Results_all$pH,Results_all$CVpH)#-0.49 significant
cor.test(Results_all$evenness,Results_all$aggregation) #-0.22 significant
cor.test(Results_all$herb_cover,Results_all$aggregation)# 0.11 insignificant




################### classification tree #######################33333




mydata=read.csv("SAR_data.csv",header=TRUE) # 162 sites
mydata$delta=apply(mydata[,c(12,13,14)], 1, median)-apply(mydata[,c(12,13,14)], 1, min) 

median(mydata$delta)# median delta AICc 110
median(mydata$R_log) # median Rsquared 0.99
#mydata=mydata[-which(mydata$delta<7),] # remove sites where we are not sure about best model

# altogether 165 sites
a_Michaelis=sum(mydata$best_model==3)# 33% 56
a_log=sum(mydata$best_model==2) # 50% 85
a_power_law=sum(mydata$best_model==1)# 17% 30

attach(mydata)
treedata=data.frame(evenness,site_richness,aggregation,herb_cover,woody_cover,best_model,lat_decimal,long_decimal)
treedata$best_model[which(treedata$best_model==3)]="M" # Michaelis menten
treedata$best_model[which(treedata$best_model==1)]="P" # power-law
treedata$best_model[which(treedata$best_model==2)]="L" # Logarithmic

treedata$best_model=factor(treedata$best_model)

ctree.model = ctree(best_model ~ evenness+aggregation+herb_cover+woody_cover+lat_decimal+long_decimal,data = treedata)

plot(ctree.model)



############## appendix estimating the bias of b0 #######################
par(mar=c(7.1, 6.1, 4.1, 2.1))
par(mfrow=c(1,2))
Results_all=read.csv("SAR_data.csv",header=TRUE)
Results_all=Results_all[-which(Results_all$R_log<0.90),]# remove 5 sites where gleason Rsquare is lower than 0.9 (median Rsquare is 0.99)
# comparing the intercept of the log model with local scale richness to estimate the bias


plot(Results_all$alpha,Results_all$b0, ylab="b0",xlab="sampling unit richness",cex.lab=1.4,cex.axis=1.6,xlim=c(0,12))
fit1=lm('b0~alpha',data=Results_all)
abline(fit1)
i=round(fit1$coefficients[1],digit=2) # intercept
s=round(fit1$coefficients[2],digit=2) # slope
formula=paste("y = ",s,"x",i)
text(4,12,formula,cex=1.2)


#transform
Results_all$b0=zVar(Results_all$b0)
Results_all$alpha=zVar(Results_all$alpha)

plot(Results_all$alpha,Results_all$b0, ylab="b0 (standardized)",xlab="sampling unit richness (standardized)",cex.lab=1.4,cex.axis=1.6)
fit2=lm('b0~alpha',data=Results_all)
abline(fit2)
i=round(fit2$coefficients[1],digit=2) # intercept
s=round(fit2$coefficients[2],digit=2) # slope
formula=paste("y = ",s,"x +",i)
text(0,3,formula,cex=1.2)
stargazer(fit1,fit2, type = 'text')


